@@ -66,6 +66,7 @@ class RequestField(RequestFieldBase):
             return False
         return self.__dict__ == other.__dict__
 
+
 def DeprecationWarningOnce(func=None, *, prefix=None):
     def decorator(func):
         warned = False
@@ -1151,7 +1152,7 @@ class ApiClient:
             self.default_headers[header_name] = header_value
         self.cookie = cookie
         # Set default User-Agent.
-        self.user_agent = 'Konfig/10.34.3/python'
+        self.user_agent = 'Konfig/10.34.13/python'
 
     def __enter__(self):
         return self
@@ -1199,9 +1200,10 @@ class ApiClient:
         fields: typing.Optional[typing.Tuple[typing.Tuple[str, str], ...]] = None,
         auth_settings: typing.Optional[typing.List[str]] = None,
         stream: bool = False,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         host: typing.Optional[str] = None,
         prefix_separator_iterator: PrefixSeparatorIterator = None,
+        **kwargs
     ) -> AsyncResponseWrapper:
 
         # header parameters
@@ -1259,6 +1261,7 @@ class ApiClient:
             body=serialized_body,
             stream=stream,
             timeout=timeout,
+            **kwargs
         )
 
 
@@ -1274,7 +1277,7 @@ class ApiClient:
         fields: typing.Optional[typing.Tuple[typing.Tuple[str, str], ...]] = None,
         auth_settings: typing.Optional[typing.List[str]] = None,
         stream: bool = False,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         host: typing.Optional[str] = None,
         prefix_separator_iterator: PrefixSeparatorIterator = None,
     ) -> ResponseWrapper:
@@ -1349,9 +1352,10 @@ class ApiClient:
         fields: typing.Optional[typing.Tuple[typing.Tuple[str, str], ...]] = None,
         auth_settings: typing.Optional[typing.List[str]] = None,
         stream: bool = False,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         host: typing.Optional[str] = None,
         prefix_separator_iterator: PrefixSeparatorIterator = None,
+        **kwargs
     ) -> AsyncResponseWrapper:
         """Makes the HTTP request (synchronous) and returns deserialized data.
 
@@ -1389,6 +1393,7 @@ class ApiClient:
             timeout,
             host,
             prefix_separator_iterator,
+            **kwargs
         )
 
     def call_api(
@@ -1401,7 +1406,7 @@ class ApiClient:
         fields: typing.Optional[typing.Tuple[typing.Tuple[str, str], ...]] = None,
         auth_settings: typing.Optional[typing.List[str]] = None,
         stream: bool = False,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         host: typing.Optional[str] = None,
         prefix_separator_iterator: PrefixSeparatorIterator = None,
     ) -> ResponseWrapper:
@@ -1461,7 +1466,8 @@ class ApiClient:
         fields: typing.Optional[typing.Tuple[typing.Tuple[str, str], ...]] = None,
         body: typing.Optional[typing.Union[str, bytes]] = None,
         stream: bool = False,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
+        **kwargs
     ) -> AsyncResponseWrapper:
         if body and fields:
             raise ApiValueError("body parameter cannot be used with fields parameter")
@@ -1473,26 +1479,25 @@ class ApiClient:
         session = aiohttp.ClientSession()
         t1 = time.time()
         if method == "GET":
-            session.get(url)
-            response = await session.get(url, headers=headers)
+            response = await session.get(url, headers=headers, timeout=timeout, **kwargs)
             return AsyncResponseWrapper(response, time.time() - t1, session)
         elif method == "HEAD":
-            response = await session.head(url, headers=headers)
+            response = await session.head(url, headers=headers, timeout=timeout, **kwargs)
             return AsyncResponseWrapper(response, time.time() - t1, session)
         elif method == "OPTIONS":
-            response = await session.options(url, data=data, headers=headers)
+            response = await session.options(url, data=data, headers=headers, timeout=timeout, **kwargs)
             return AsyncResponseWrapper(response, time.time() - t1, session)
         elif method == "POST":
-            response = await session.post(url, data=data, headers=headers)
+            response = await session.post(url, data=data, headers=headers, timeout=timeout, **kwargs)
             return AsyncResponseWrapper(response, time.time() - t1, session)
         elif method == "PUT":
-            response = await session.put(url, data=data, headers=headers)
+            response = await session.put(url, data=data, headers=headers, timeout=timeout, **kwargs)
             return AsyncResponseWrapper(response, time.time() - t1, session)
         elif method == "PATCH":
-            response = await session.patch(url, data=data, headers=headers)
+            response = await session.patch(url, data=data, headers=headers, timeout=timeout, **kwargs)
             return AsyncResponseWrapper(response, time.time() - t1, session)
         elif method == "DELETE":
-            response = await session.delete(url, data=data, headers=headers)
+            response = await session.delete(url, data=data, headers=headers, timeout=timeout, **kwargs)
             return AsyncResponseWrapper(response, time.time() - t1, session)
         raise ApiValueError(
             "http method must be `GET`, `HEAD`, `OPTIONS`,"
@@ -1507,7 +1512,7 @@ class ApiClient:
         fields: typing.Optional[typing.Tuple[typing.Tuple[str, str], ...]] = None,
         body: typing.Optional[typing.Union[str, bytes]] = None,
         stream: bool = False,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
     ) -> ResponseWrapper:
         """Makes the HTTP request using RESTClient."""
         if method == "GET":
