@@ -32,43 +32,25 @@ import frozendict  # noqa: F401
 
 from snaptrade_client import schemas  # noqa: F401
 
-from snaptrade_client.model.manual_trade import ManualTrade as ManualTradeSchema
-from snaptrade_client.model.cash_restriction import CashRestriction as CashRestrictionSchema
+from snaptrade_client.model.manual_trade_and_impact import ManualTradeAndImpact as ManualTradeAndImpactSchema
+from snaptrade_client.model.action import Action as ActionSchema
 from snaptrade_client.model.model400_failed_request_response import Model400FailedRequestResponse as Model400FailedRequestResponseSchema
 from snaptrade_client.model.stop_price import StopPrice as StopPriceSchema
-from snaptrade_client.model.manual_trade_balance import ManualTradeBalance as ManualTradeBalanceSchema
 from snaptrade_client.model.time_in_force import TimeInForce as TimeInForceSchema
-from snaptrade_client.model.account_meta import AccountMeta as AccountMetaSchema
 from snaptrade_client.model.order_type import OrderType as OrderTypeSchema
 from snaptrade_client.model.manual_trade_form import ManualTradeForm as ManualTradeFormSchema
 from snaptrade_client.model.model403_failed_request_response import Model403FailedRequestResponse as Model403FailedRequestResponseSchema
 from snaptrade_client.model.price import Price as PriceSchema
-from snaptrade_client.model.manual_trade_and_impact import ManualTradeAndImpact as ManualTradeAndImpactSchema
-from snaptrade_client.model.manual_trade_symbol import ManualTradeSymbol as ManualTradeSymbolSchema
-from snaptrade_client.model.action import Action as ActionSchema
-from snaptrade_client.model.account import Account as AccountSchema
-from snaptrade_client.model.cash import Cash as CashSchema
-from snaptrade_client.model.account_sync_status import AccountSyncStatus as AccountSyncStatusSchema
-from snaptrade_client.model.currency import Currency as CurrencySchema
 
+from snaptrade_client.type.action import Action
 from snaptrade_client.type.time_in_force import TimeInForce
+from snaptrade_client.type.manual_trade_form import ManualTradeForm
 from snaptrade_client.type.manual_trade_and_impact import ManualTradeAndImpact
 from snaptrade_client.type.model400_failed_request_response import Model400FailedRequestResponse
-from snaptrade_client.type.account_meta import AccountMeta
 from snaptrade_client.type.stop_price import StopPrice
-from snaptrade_client.type.currency import Currency
 from snaptrade_client.type.model403_failed_request_response import Model403FailedRequestResponse
 from snaptrade_client.type.price import Price
-from snaptrade_client.type.manual_trade import ManualTrade
 from snaptrade_client.type.order_type import OrderType
-from snaptrade_client.type.action import Action
-from snaptrade_client.type.account import Account
-from snaptrade_client.type.manual_trade_form import ManualTradeForm
-from snaptrade_client.type.cash import Cash
-from snaptrade_client.type.cash_restriction import CashRestriction
-from snaptrade_client.type.manual_trade_symbol import ManualTradeSymbol
-from snaptrade_client.type.account_sync_status import AccountSyncStatus
-from snaptrade_client.type.manual_trade_balance import ManualTradeBalance
 
 from . import path
 
@@ -227,8 +209,9 @@ class BaseApi(api_client.Api):
         price: typing.Optional[Price] = None,
         stop: typing.Optional[StopPrice] = None,
         time_in_force: typing.Optional[TimeInForce] = None,
-        units: typing.Optional[typing.Union[int, float]] = None,
+        units: typing.Optional[float] = None,
         universal_symbol_id: typing.Optional[str] = None,
+        notional_value: typing.Optional[float] = None,
         query_params: typing.Optional[dict] = {},
     ) -> api_client.MappedArgs:
         args: api_client.MappedArgs = api_client.MappedArgs()
@@ -250,6 +233,8 @@ class BaseApi(api_client.Api):
             _body["units"] = units
         if universal_symbol_id is not None:
             _body["universal_symbol_id"] = universal_symbol_id
+        if notional_value is not None:
+            _body["notional_value"] = notional_value
         args.body = body if body is not None else _body
         if user_id is not None:
             _query_params["userId"] = user_id
@@ -263,10 +248,11 @@ class BaseApi(api_client.Api):
         body: typing.Any = None,
         query_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
         content_type: str = 'application/json',
         stream: bool = False,
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -332,6 +318,7 @@ class BaseApi(api_client.Api):
             auth_settings=_auth,
             prefix_separator_iterator=prefix_separator_iterator,
             timeout=timeout,
+            **kwargs
         )
     
         if stream:
@@ -393,7 +380,7 @@ class BaseApi(api_client.Api):
         body: typing.Any = None,
         query_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
         content_type: str = 'application/json',
         stream: bool = False,
@@ -501,9 +488,11 @@ class GetOrderImpact(BaseApi):
         price: typing.Optional[Price] = None,
         stop: typing.Optional[StopPrice] = None,
         time_in_force: typing.Optional[TimeInForce] = None,
-        units: typing.Optional[typing.Union[int, float]] = None,
+        units: typing.Optional[float] = None,
         universal_symbol_id: typing.Optional[str] = None,
+        notional_value: typing.Optional[float] = None,
         query_params: typing.Optional[dict] = {},
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -522,10 +511,12 @@ class GetOrderImpact(BaseApi):
             time_in_force=time_in_force,
             units=units,
             universal_symbol_id=universal_symbol_id,
+            notional_value=notional_value,
         )
         return await self._aget_order_impact_oapg(
             body=args.body,
             query_params=args.query,
+            **kwargs,
         )
     
     def get_order_impact(
@@ -539,8 +530,9 @@ class GetOrderImpact(BaseApi):
         price: typing.Optional[Price] = None,
         stop: typing.Optional[StopPrice] = None,
         time_in_force: typing.Optional[TimeInForce] = None,
-        units: typing.Optional[typing.Union[int, float]] = None,
+        units: typing.Optional[float] = None,
         universal_symbol_id: typing.Optional[str] = None,
+        notional_value: typing.Optional[float] = None,
         query_params: typing.Optional[dict] = {},
     ) -> typing.Union[
         ApiResponseFor200,
@@ -559,6 +551,7 @@ class GetOrderImpact(BaseApi):
             time_in_force=time_in_force,
             units=units,
             universal_symbol_id=universal_symbol_id,
+            notional_value=notional_value,
         )
         return self._get_order_impact_oapg(
             body=args.body,
@@ -579,9 +572,11 @@ class ApiForpost(BaseApi):
         price: typing.Optional[Price] = None,
         stop: typing.Optional[StopPrice] = None,
         time_in_force: typing.Optional[TimeInForce] = None,
-        units: typing.Optional[typing.Union[int, float]] = None,
+        units: typing.Optional[float] = None,
         universal_symbol_id: typing.Optional[str] = None,
+        notional_value: typing.Optional[float] = None,
         query_params: typing.Optional[dict] = {},
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -600,10 +595,12 @@ class ApiForpost(BaseApi):
             time_in_force=time_in_force,
             units=units,
             universal_symbol_id=universal_symbol_id,
+            notional_value=notional_value,
         )
         return await self._aget_order_impact_oapg(
             body=args.body,
             query_params=args.query,
+            **kwargs,
         )
     
     def post(
@@ -617,8 +614,9 @@ class ApiForpost(BaseApi):
         price: typing.Optional[Price] = None,
         stop: typing.Optional[StopPrice] = None,
         time_in_force: typing.Optional[TimeInForce] = None,
-        units: typing.Optional[typing.Union[int, float]] = None,
+        units: typing.Optional[float] = None,
         universal_symbol_id: typing.Optional[str] = None,
+        notional_value: typing.Optional[float] = None,
         query_params: typing.Optional[dict] = {},
     ) -> typing.Union[
         ApiResponseFor200,
@@ -637,6 +635,7 @@ class ApiForpost(BaseApi):
             time_in_force=time_in_force,
             units=units,
             universal_symbol_id=universal_symbol_id,
+            notional_value=notional_value,
         )
         return self._get_order_impact_oapg(
             body=args.body,
