@@ -32,47 +32,25 @@ import frozendict  # noqa: F401
 
 from snaptrade_client import schemas  # noqa: F401
 
-from snaptrade_client.model.exchange import Exchange as ExchangeSchema
+from snaptrade_client.model.action import Action as ActionSchema
 from snaptrade_client.model.model400_failed_request_response import Model400FailedRequestResponse as Model400FailedRequestResponseSchema
 from snaptrade_client.model.stop_price import StopPrice as StopPriceSchema
 from snaptrade_client.model.time_in_force import TimeInForce as TimeInForceSchema
-from snaptrade_client.model.security_type import SecurityType as SecurityTypeSchema
+from snaptrade_client.model.account_order_record import AccountOrderRecord as AccountOrderRecordSchema
 from snaptrade_client.model.order_type import OrderType as OrderTypeSchema
 from snaptrade_client.model.manual_trade_form import ManualTradeForm as ManualTradeFormSchema
 from snaptrade_client.model.model403_failed_request_response import Model403FailedRequestResponse as Model403FailedRequestResponseSchema
 from snaptrade_client.model.price import Price as PriceSchema
-from snaptrade_client.model.action import Action as ActionSchema
-from snaptrade_client.model.options_symbol import OptionsSymbol as OptionsSymbolSchema
-from snaptrade_client.model.filled_units import FilledUnits as FilledUnitsSchema
-from snaptrade_client.model.cancelled_units import CancelledUnits as CancelledUnitsSchema
-from snaptrade_client.model.account_order_record import AccountOrderRecord as AccountOrderRecordSchema
-from snaptrade_client.model.currency import Currency as CurrencySchema
-from snaptrade_client.model.underlying_symbol import UnderlyingSymbol as UnderlyingSymbolSchema
-from snaptrade_client.model.us_exchange import USExchange as USExchangeSchema
-from snaptrade_client.model.universal_symbol import UniversalSymbol as UniversalSymbolSchema
-from snaptrade_client.model.open_units import OpenUnits as OpenUnitsSchema
-from snaptrade_client.model.account_order_record_status import AccountOrderRecordStatus as AccountOrderRecordStatusSchema
 
-from snaptrade_client.type.account_order_record_status import AccountOrderRecordStatus
+from snaptrade_client.type.action import Action
 from snaptrade_client.type.time_in_force import TimeInForce
-from snaptrade_client.type.security_type import SecurityType
-from snaptrade_client.type.filled_units import FilledUnits
+from snaptrade_client.type.manual_trade_form import ManualTradeForm
 from snaptrade_client.type.model400_failed_request_response import Model400FailedRequestResponse
 from snaptrade_client.type.stop_price import StopPrice
-from snaptrade_client.type.currency import Currency
 from snaptrade_client.type.model403_failed_request_response import Model403FailedRequestResponse
+from snaptrade_client.type.account_order_record import AccountOrderRecord
 from snaptrade_client.type.price import Price
 from snaptrade_client.type.order_type import OrderType
-from snaptrade_client.type.action import Action
-from snaptrade_client.type.cancelled_units import CancelledUnits
-from snaptrade_client.type.options_symbol import OptionsSymbol
-from snaptrade_client.type.manual_trade_form import ManualTradeForm
-from snaptrade_client.type.exchange import Exchange
-from snaptrade_client.type.us_exchange import USExchange
-from snaptrade_client.type.underlying_symbol import UnderlyingSymbol
-from snaptrade_client.type.open_units import OpenUnits
-from snaptrade_client.type.universal_symbol import UniversalSymbol
-from snaptrade_client.type.account_order_record import AccountOrderRecord
 
 from . import path
 
@@ -231,8 +209,9 @@ class BaseApi(api_client.Api):
         price: typing.Optional[Price] = None,
         stop: typing.Optional[StopPrice] = None,
         time_in_force: typing.Optional[TimeInForce] = None,
-        units: typing.Optional[typing.Union[int, float]] = None,
+        units: typing.Optional[float] = None,
         universal_symbol_id: typing.Optional[str] = None,
+        notional_value: typing.Optional[float] = None,
         query_params: typing.Optional[dict] = {},
     ) -> api_client.MappedArgs:
         args: api_client.MappedArgs = api_client.MappedArgs()
@@ -254,6 +233,8 @@ class BaseApi(api_client.Api):
             _body["units"] = units
         if universal_symbol_id is not None:
             _body["universal_symbol_id"] = universal_symbol_id
+        if notional_value is not None:
+            _body["notional_value"] = notional_value
         args.body = body if body is not None else _body
         if user_id is not None:
             _query_params["userId"] = user_id
@@ -267,10 +248,11 @@ class BaseApi(api_client.Api):
         body: typing.Any = None,
         query_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
         content_type: str = 'application/json',
         stream: bool = False,
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -336,6 +318,7 @@ class BaseApi(api_client.Api):
             auth_settings=_auth,
             prefix_separator_iterator=prefix_separator_iterator,
             timeout=timeout,
+            **kwargs
         )
     
         if stream:
@@ -397,7 +380,7 @@ class BaseApi(api_client.Api):
         body: typing.Any = None,
         query_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
         content_type: str = 'application/json',
         stream: bool = False,
@@ -505,9 +488,11 @@ class PlaceForceOrder(BaseApi):
         price: typing.Optional[Price] = None,
         stop: typing.Optional[StopPrice] = None,
         time_in_force: typing.Optional[TimeInForce] = None,
-        units: typing.Optional[typing.Union[int, float]] = None,
+        units: typing.Optional[float] = None,
         universal_symbol_id: typing.Optional[str] = None,
+        notional_value: typing.Optional[float] = None,
         query_params: typing.Optional[dict] = {},
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -526,10 +511,12 @@ class PlaceForceOrder(BaseApi):
             time_in_force=time_in_force,
             units=units,
             universal_symbol_id=universal_symbol_id,
+            notional_value=notional_value,
         )
         return await self._aplace_force_order_oapg(
             body=args.body,
             query_params=args.query,
+            **kwargs,
         )
     
     def place_force_order(
@@ -543,8 +530,9 @@ class PlaceForceOrder(BaseApi):
         price: typing.Optional[Price] = None,
         stop: typing.Optional[StopPrice] = None,
         time_in_force: typing.Optional[TimeInForce] = None,
-        units: typing.Optional[typing.Union[int, float]] = None,
+        units: typing.Optional[float] = None,
         universal_symbol_id: typing.Optional[str] = None,
+        notional_value: typing.Optional[float] = None,
         query_params: typing.Optional[dict] = {},
     ) -> typing.Union[
         ApiResponseFor200,
@@ -563,6 +551,7 @@ class PlaceForceOrder(BaseApi):
             time_in_force=time_in_force,
             units=units,
             universal_symbol_id=universal_symbol_id,
+            notional_value=notional_value,
         )
         return self._place_force_order_oapg(
             body=args.body,
@@ -583,9 +572,11 @@ class ApiForpost(BaseApi):
         price: typing.Optional[Price] = None,
         stop: typing.Optional[StopPrice] = None,
         time_in_force: typing.Optional[TimeInForce] = None,
-        units: typing.Optional[typing.Union[int, float]] = None,
+        units: typing.Optional[float] = None,
         universal_symbol_id: typing.Optional[str] = None,
+        notional_value: typing.Optional[float] = None,
         query_params: typing.Optional[dict] = {},
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -604,10 +595,12 @@ class ApiForpost(BaseApi):
             time_in_force=time_in_force,
             units=units,
             universal_symbol_id=universal_symbol_id,
+            notional_value=notional_value,
         )
         return await self._aplace_force_order_oapg(
             body=args.body,
             query_params=args.query,
+            **kwargs,
         )
     
     def post(
@@ -621,8 +614,9 @@ class ApiForpost(BaseApi):
         price: typing.Optional[Price] = None,
         stop: typing.Optional[StopPrice] = None,
         time_in_force: typing.Optional[TimeInForce] = None,
-        units: typing.Optional[typing.Union[int, float]] = None,
+        units: typing.Optional[float] = None,
         universal_symbol_id: typing.Optional[str] = None,
+        notional_value: typing.Optional[float] = None,
         query_params: typing.Optional[dict] = {},
     ) -> typing.Union[
         ApiResponseFor200,
@@ -641,6 +635,7 @@ class ApiForpost(BaseApi):
             time_in_force=time_in_force,
             units=units,
             universal_symbol_id=universal_symbol_id,
+            notional_value=notional_value,
         )
         return self._place_force_order_oapg(
             body=args.body,
