@@ -13,12 +13,17 @@
 from datetime import datetime, date
 import typing
 from enum import Enum
-from typing_extensions import TypedDict, Literal
+from typing_extensions import TypedDict, Literal, TYPE_CHECKING
 
 from snaptrade_client.type.account_order_record_status import AccountOrderRecordStatus
 from snaptrade_client.type.action import Action
+from snaptrade_client.type.cancelled_units import CancelledUnits
+from snaptrade_client.type.filled_units import FilledUnits
+from snaptrade_client.type.open_units import OpenUnits
 from snaptrade_client.type.options_symbol import OptionsSymbol
 from snaptrade_client.type.order_type import OrderType
+from snaptrade_client.type.price import Price
+from snaptrade_client.type.stop_price import StopPrice
 from snaptrade_client.type.time_in_force import TimeInForce
 from snaptrade_client.type.universal_symbol import UniversalSymbol
 
@@ -39,26 +44,20 @@ class OptionalAccountOrderRecord(TypedDict, total=False):
 
     action: Action
 
-    # Trade Units
+    # Trade Units. Cannot work with notional value.
     total_quantity: typing.Union[int, float]
 
-    # Trade Units
-    open_quantity: typing.Union[int, float]
+    open_quantity: OpenUnits
 
-    # Trade Units
-    canceled_quantity: typing.Union[int, float]
+    canceled_quantity: CancelledUnits
 
-    # Trade Units
-    filled_quantity: typing.Union[int, float]
+    filled_quantity: FilledUnits
 
-    # Trade Price if limit or stop limit order
-    execution_price: typing.Union[int, float]
+    execution_price: Price
 
-    # Trade Price if limit or stop limit order
-    limit_price: typing.Union[int, float]
+    limit_price: Price
 
-    # Trade Price if limit or stop limit order
-    stop_price: typing.Union[int, float]
+    stop_price: StopPrice
 
     order_type: OrderType
 
