@@ -13,10 +13,11 @@
 from datetime import datetime, date
 import typing
 from enum import Enum
-from typing_extensions import TypedDict, Literal
+from typing_extensions import TypedDict, Literal, TYPE_CHECKING
 
 from snaptrade_client.type.action import Action
 from snaptrade_client.type.order_type import OrderType
+from snaptrade_client.type.price import Price
 from snaptrade_client.type.stop_price import StopPrice
 from snaptrade_client.type.time_in_force import TimeInForce
 
@@ -30,17 +31,17 @@ class OptionalManualTradeForm(TypedDict, total=False):
 
     order_type: OrderType
 
-    # Trade Price if limit or stop limit order
-    price: typing.Union[int, float]
+    price: Price
 
     stop: StopPrice
 
     time_in_force: TimeInForce
 
-    # Trade Units
-    units: typing.Union[int, float]
+    units: float
 
     universal_symbol_id: str
 
+    notional_value: float
+
 class ManualTradeForm(RequiredManualTradeForm, OptionalManualTradeForm):
     pass
