@@ -13,7 +13,7 @@
 from datetime import datetime, date
 import typing
 from enum import Enum
-from typing_extensions import TypedDict, Literal
+from typing_extensions import TypedDict, Literal, TYPE_CHECKING
 
 from snaptrade_client.type.account_simple import AccountSimple
 from snaptrade_client.type.currency import Currency
@@ -36,7 +36,7 @@ class OptionalUniversalActivity(TypedDict, total=False):
 
     fee: typing.Union[int, float]
 
-    # The forex conversion rate involved in the transaction if provided by the brokerage
+    # The forex conversion rate involved in the transaction if provided by the brokerage. Used in cases where securities of one currency are purchased in a different currency, and the forex conversion is automatic. In those cases, price, amount and fee will be in the top level currency (activity -> currency)
     fx_rate: typing.Optional[typing.Union[int, float]]
 
     institution: str
